@@ -10,7 +10,7 @@ use Object::Pad;
 
 class Geo::Location::IP::Model::AnonymousIP;
 
-our $VERSION = 0.002;
+our $VERSION = 0.003;
 
 apply Geo::Location::IP::Role::HasIPAddress;
 
@@ -21,33 +21,17 @@ field $is_public_proxy :param :reader      = 0;
 field $is_residential_proxy :param :reader = 0;
 field $is_tor_exit_node :param :reader     = 0;
 
-#<<<
-ADJUST :params (:$raw = {}) {
-    if (exists $raw->{is_anonymous}) {
-        $is_anonymous = $raw->{is_anonymous};
-    }
-
-    if (exists $raw->{is_anonymous_vpn}) {
-        $is_anonymous_vpn = $raw->{is_anonymous_vpn};
-    }
-
-    if (exists $raw->{is_hosting_provider}) {
-        $is_hosting_provider = $raw->{is_hosting_provider};
-    }
-
-    if (exists $raw->{is_public_proxy}) {
-        $is_public_proxy = $raw->{is_public_proxy};
-    }
-
-    if (exists $raw->{is_residential_proxy}) {
-        $is_residential_proxy = $raw->{is_residential_proxy};
-    }
-
-    if (exists $raw->{is_tor_exit_node}) {
-        $is_tor_exit_node = $raw->{is_tor_exit_node};
-    }
+sub _from_hash ($class, $hash_ref, $ip_address) {
+    return $class->new(
+        ip_address           => $ip_address,
+        is_anonymous         => $hash_ref->{is_anonymous}         // 0,
+        is_anonymous_vpn     => $hash_ref->{is_anonymous_vpn}     // 0,
+        is_hosting_provider  => $hash_ref->{is_hosting_provider}  // 0,
+        is_public_proxy      => $hash_ref->{is_public_proxy}      // 0,
+        is_residential_proxy => $hash_ref->{is_residential_proxy} // 0,
+        is_tor_exit_node     => $hash_ref->{is_tor_exit_node}     // 0,
+    );
 }
-#>>>
 
 1;
 __END__
@@ -60,7 +44,7 @@ Geo::Location::IP::Model::AnonymousIP - Anonymity details
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -107,39 +91,39 @@ object.
 
   my $is_anonymous = $anon_ip_model->is_anonymous;
 
-Returns true if the IP address belongs to any sort of anonymous network.
+Returns true if the C<ip_address> belongs to any sort of anonymous network.
 
 =head2 is_anonymous_vpn
 
   my $is_anonymous_vpn = $anon_ip_model->is_anonymous_vpn;
 
-Returns true if the IP address is known to belong to an anonymous VPN
+Returns true if the C<ip_address> is known to belong to an anonymous VPN
 provider.
 
 =head2 is_hosting_provider
 
   my $is_hosting_provider = $anon_ip_model->is_hosting_provider;
 
-Returns true if the IP address belongs to a hosting provider.
+Returns true if the C<ip_address> belongs to a hosting provider.
 
 =head2 is_public_proxy
 
   my $is_public_proxy = $anon_ip_model->is_public_proxy;
 
-Returns true if the IP address belongs to a public proxy.
+Returns true if the C<ip_address> belongs to a public proxy.
 
 =head2 is_residential_proxy
 
   my $is_residential_proxy = $anon_ip_model->is_residential_proxy;
 
-Returns true if the IP address is on a suspected anonymizing network and
+Returns true if the C<ip_address> is on a suspected anonymizing network and
 belongs to a residential ISP.
 
 =head2 is_tor_exit_node
 
   my $is_tor_exit_node = $anon_ip_model->is_tor_exit_node;
 
-Returns true if the IP address is a Tor exit node.
+Returns true if the C<ip_address> belongs to a Tor exit node.
 
 =for Pod::Coverage DOES META
 
