@@ -10,7 +10,7 @@ use Object::Pad;
 
 class Geo::Location::IP::Model::City;
 
-our $VERSION = 0.002;
+our $VERSION = 0.003;
 
 use Geo::Location::IP::Record::City;
 use Geo::Location::IP::Record::Continent;
@@ -22,16 +22,16 @@ use Geo::Location::IP::Record::RepresentedCountry;
 use Geo::Location::IP::Record::Subdivision;
 use Geo::Location::IP::Record::Traits;
 
-field $city :reader;
-field $continent :reader;
-field $country :reader;
-field $location :reader;
-field $maxmind :reader;
-field $postal :reader;
-field $registered_country :reader;
-field $represented_country :reader;
-field $subdivisions;
-field $traits :reader;
+field $city :param :reader;
+field $continent :param :reader;
+field $country :param :reader;
+field $location :param :reader;
+field $maxmind :param :reader;
+field $postal :param :reader;
+field $registered_country :param :reader;
+field $represented_country :param :reader;
+field $subdivisions :param;
+field $traits :param :reader;
 
 method most_specific_subdivision () {
     if (@{$subdivisions} > 0) {
@@ -47,61 +47,57 @@ method subdivisions () {
     return @{$subdivisions};
 }
 
-#<<<
-ADJUST :params (:$raw = {}, :$ip_address = undef, :$locales = undef) {
-    if (!defined $locales) {
-        $locales = ['en'];
-    }
+sub _from_hash ($class, $hash_ref, $ip_address, $locales) {
+    my $city
+        = Geo::Location::IP::Record::City->_from_hash($hash_ref->{city} // {},
+        $locales);
 
-    $city = Geo::Location::IP::Record::City->_from_hash(
-        $raw->{city} // {},
-        $locales
-    );
+    my $continent = Geo::Location::IP::Record::Continent->_from_hash(
+        $hash_ref->{continent} // {}, $locales);
 
-    $continent = Geo::Location::IP::Record::Continent->_from_hash(
-        $raw->{continent} // {},
-        $locales
-    );
+    my $country
+        = Geo::Location::IP::Record::Country->_from_hash($hash_ref->{country}
+            // {}, $locales);
 
-    $country = Geo::Location::IP::Record::Country->_from_hash(
-        $raw->{country} // {},
-        $locales
-    );
+    my $location = Geo::Location::IP::Record::Location->_from_hash(
+        $hash_ref->{location} // {});
 
-    $location = Geo::Location::IP::Record::Location->_from_hash(
-        $raw->{location} // {}
-    );
+    my $maxmind
+        = Geo::Location::IP::Record::MaxMind->_from_hash($hash_ref->{maxmind}
+            // {});
 
-    $maxmind = Geo::Location::IP::Record::MaxMind->_from_hash(
-        $raw->{maxmind} // {}
-    );
+    my $postal
+        = Geo::Location::IP::Record::Postal->_from_hash($hash_ref->{postal}
+            // {});
 
-    $postal = Geo::Location::IP::Record::Postal->_from_hash(
-        $raw->{postal} // {}
-    );
+    my $registered_country = Geo::Location::IP::Record::Country->_from_hash(
+        $hash_ref->{registered_country} // {}, $locales);
 
-    $registered_country = Geo::Location::IP::Record::Country->_from_hash(
-        $raw->{registered_country} // {},
-        $locales
-    );
-
-    $represented_country
+    my $represented_country
         = Geo::Location::IP::Record::RepresentedCountry->_from_hash(
-        $raw->{represented_country} // {},
-        $locales
-    );
+        $hash_ref->{represented_country} // {}, $locales);
 
     my @subdivisions = map {
         Geo::Location::IP::Record::Subdivision->_from_hash($_, $locales)
-    } @{$raw->{subdivisions} // []};
-    $subdivisions = \@subdivisions;
+    } @{$hash_ref->{subdivisions} // []};
 
-    $traits = Geo::Location::IP::Record::Traits->_from_hash(
-        $raw->{traits} // {},
-        $ip_address
+    my $traits
+        = Geo::Location::IP::Record::Traits->_from_hash($hash_ref->{traits}
+            // {}, $ip_address);
+
+    return $class->new(
+        city                => $city,
+        continent           => $continent,
+        country             => $country,
+        location            => $location,
+        maxmind             => $maxmind,
+        postal              => $postal,
+        registered_country  => $registered_country,
+        represented_country => $represented_country,
+        subdivisions        => \@subdivisions,
+        traits              => $traits,
     );
 }
-#>>>
 
 1;
 __END__
@@ -114,7 +110,7 @@ Geo::Location::IP::Model::City - Records associated with a city
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -132,34 +128,25 @@ version 0.002
 
 =head1 DESCRIPTION
 
-This class contains records from an IP address query in a city database.
+This class contains records from a city database.
 
 =head1 SUBROUTINES/METHODS
 
 =head2 new
 
   my $city_model = Geo::Location::IP::Model::City->new(
-    raw => {
-        city                => {names    => {en => 'Berlin'}},
-        continent           => {names    => {en => 'Europe'}},
-        country             => {names    => {en => 'Germany'}},
-        location            => {latitude => 52.52, longitude => 13.41},
-        maxmind             => {queries_remaining => 9999},
-        registered_country  => {names    => {en => 'Germany'}},
-        represented_country => {
-          names => {en => 'United States'},
-          type  => 'military',
-        },
-        subdivisions => [
-          {names => {en => 'Berlin'}, iso_code => 'BE'},
-        ],
-        traits => {domain => 'example.com'},
-    },
-    ip_address => $ip_address,
-    locales    => ['en'],
+    city                => $city,
+    continent           => $continent,
+    country             => $country,
+    location            => $location,
+    maxmind             => $maxmind,
+    registered_country  => $registered_country,
+    represented_country => $represented_country,
+    subdivisions        => \@subdivisions,
+    traits              => $traits,
   );
 
-Creates a new object.
+Creates a new object with records from an IP address query in a city database.
 
 All records may contain undefined values.
 
