@@ -10,19 +10,20 @@ use Object::Pad;
 
 class Geo::Location::IP::Model::ConnectionType;
 
-our $VERSION = 0.002;
+our $VERSION = 0.003;
 
 apply Geo::Location::IP::Role::HasIPAddress;
 
-field $connection_type :param :reader = undef;
+field $connection_type :param :reader;
 
-#<<<
-ADJUST :params (:$raw = {}) {
-    if (exists $raw->{connection_type}) {
-        $connection_type = $raw->{connection_type};
-    }
+sub _from_hash ($class, $hash_ref, $ip_address) {
+    my $connection_type = $hash_ref->{connection_type} // undef;
+
+    return $class->new(
+        connection_type => $connection_type,
+        ip_address      => $ip_address,
+    );
 }
-#>>>
 
 1;
 __END__
@@ -35,7 +36,7 @@ Geo::Location::IP::Model::ConnectionType - IP connection details
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
